pynetstim
=========

pynetstim is a python module that aims to create an integrated framework for brain network stimulation, stimulation targeting and engagement, visualization, and stimulation individualization using multimodal imaging.

	
Dependencies
=============

- python>=3.5
- Scipy
- Nilearn
- Nibabel
- Pysurfer
- Pandas
- Nipype
- MNE
- Mayavi


Install
========

Please make sure you have installed all the dependencies listed above. pynetstim can ben installed by running the following command: 

```
pip install -U --user pynetstim
```














